@@ -1,5 +1,5 @@
 """The only file where icon filenames are mentioned"""
-from __future__ import absolute_import, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 
 from qtpy import QtGui
@@ -137,6 +137,7 @@ def status(filename, deleted, is_staged, untracked):
 
 # Icons creators and SVG file references
 
+
 def three_bars():
     return icon('three-bars.svg')
 
@@ -201,6 +202,7 @@ def discard():
 # directory is used for the File Browser, where more contrast with the file
 # icons are needed.
 
+
 def folder():
     return icon('folder.svg')
 
