@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 from functools import partial
 
 from qtpy import QtGui
@@ -351,9 +351,7 @@ class ToolbarView(standard.Dialog):
                     pass
                 icon = command.get('icon', None)
                 tooltip = command.get('tooltip', None)
-                child = create_child(
-                    parent, item, command['title'], tooltip, icon
-                )
+                child = create_child(parent, item, command['title'], tooltip, icon)
                 top.appendRow(child)
 
             top.sortChildren(0, Qt.AscendingOrder)
